==> jcudnn-0.9.2-sources.jar: jcuda/jcudnn/cudnnTensorFormat.java <==
/*
 * JCudnn - Java bindings for cuDNN, the NVIDIA CUDA
 * Deep Neural Network library, to be used with JCuda
 *
 * Copyright (c) 2015-2018 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcudnn;

public class cudnnTensorFormat
{
    /**
     * row major (wStride = 1, hStride = w) 
     */
    public static final int CUDNN_TENSOR_NCHW = 0;
    /**
     * feature maps interleaved ( cStride = 1 )
     */
    public static final int CUDNN_TENSOR_NHWC = 1;
    /**
     * each image point is vector of element of C : the length of the vector is carried by the data type
     */
    public static final int CUDNN_TENSOR_NCHW_VECT_C = 2;

    /**
     * Private constructor to prevent instantiation
     */
    private cudnnTensorFormat()
    {
        // Private constructor to prevent instantiation
    }

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUDNN_TENSOR_NCHW: return "CUDNN_TENSOR_NCHW";
            case CUDNN_TENSOR_NHWC: return "CUDNN_TENSOR_NHWC";
            case CUDNN_TENSOR_NCHW_VECT_C: return "CUDNN_TENSOR_NCHW_VECT_C";
        }
        return "INVALID cudnnTensorFormat: "+n;
    }
}

==> jcudnn-10.1.0-sources.jar: jcuda/jcudnn/cudnnTensorFormat.java <==
/*
 * JCudnn - Java bindings for cuDNN, the NVIDIA CUDA
 * Deep Neural Network library, to be used with JCuda
 *
 * Copyright (c) 2015-2018 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcudnn;

public class cudnnTensorFormat
{
    /**
     * row major (wStride = 1, hStride = w) 
     */
    public static final int CUDNN_TENSOR_NCHW = 0;
    /**
     * feature maps interleaved ( cStride = 1 )
     */
    public static final int CUDNN_TENSOR_NHWC = 1;
    /**
     * each image point is vector of element of C, vector length in data type 
     */
    public static final int CUDNN_TENSOR_NCHW_VECT_C = 2;

    /**
     * Private constructor to prevent instantiation
     */
    private cudnnTensorFormat()
    {
        // Private constructor to prevent instantiation
    }

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUDNN_TENSOR_NCHW: return "CUDNN_TENSOR_NCHW";
            case CUDNN_TENSOR_NHWC: return "CUDNN_TENSOR_NHWC";
            case CUDNN_TENSOR_NCHW_VECT_C: return "CUDNN_TENSOR_NCHW_VECT_C";
        }
        return "INVALID cudnnTensorFormat: "+n;
    }
}
